/*
  modified and extended by Torsten Brischalle

  based upon qterminalwidget from http://code.google.com/p/qterminalwidget

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/
*/

#ifndef QCONSOLEWIDGET_H
#define QCONSOLEWIDGET_H

//-----------------------------------------------------------------------------

#include <QPlainTextEdit>
#include <QDir>

#include <queue>

#include "luathread.h"

//-----------------------------------------------------------------------------

#define CONSOLE_PROMPT          "Lua>"
#define CONSOLE_MAX_NUM_LINES   200
#define CONSOLE_MAX_HISTORY     50

//-----------------------------------------------------------------------------

class QConsoleWidget : public QPlainTextEdit
{
  Q_OBJECT
public:

  QConsoleWidget(QWidget *parent = 0);
  ~QConsoleWidget();

  void AttachLuaThread(LuaThread *luaThread);

  void Write(QString szOutput);

private:
  LuaThread             *m_luaThread;
  int                   m_fixedPosition;
  std::deque <QString>  m_history;
  std::deque <QString>::const_iterator m_historyIter;

  void WriteImpl(QString szOutput);
  void WriteHistory(QString szOutput);

protected:
  void keyPressEvent (QKeyEvent * event);

public slots:
  void LuaStarted();
  void LuaStopped();

  void cursorPositionChanged();

private slots:
  void SlotWrite(QString szOutput);

signals:
  void SignalWrite(QString szOutput);
};

//-----------------------------------------------------------------------------

#endif // QCONSOLEWIDGET_H
