/*
  Copyright (C) 2012  Torsten Brischalle

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/
*/

#include "windowfunctionhelp.h"
#include "ui_windowfunctionhelp.h"

#include <QFile>
#include <QToolBar>
#include <QDir>

//-----------------------------------------------------------------------------

WindowFunctionHelp::WindowFunctionHelp(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::WindowFunctionHelp)
{
  ui->setupUi(this);

  setWindowIcon(QIcon("icons:Lua-Quick-Try-Out.png"));

  QToolBar *toolBar = new QToolBar(this);
  ui->verticalLayout->insertWidget(0, toolBar);

  m_actionHome = toolBar->addAction(QIcon(QString("icons:home.png")), QString("home"));
  m_actionBackward = toolBar->addAction(QIcon(QString("icons:backward.png")), QString("backward"));
  m_actionForward = toolBar->addAction(QIcon(QString("icons:forward.png")), QString("forward"));

  m_actionBackward->setEnabled(false);
  m_actionForward->setEnabled(false);

  connect(m_actionHome, SIGNAL(triggered()), ui->textBrowser, SLOT(home()));
  connect(m_actionBackward, SIGNAL(triggered()), ui->textBrowser, SLOT(backward()));
  connect(m_actionForward, SIGNAL(triggered()), ui->textBrowser, SLOT(forward()));

  connect(ui->textBrowser, SIGNAL(backwardAvailable(bool)), this , SLOT(backwardAvailable(bool)));
  connect(ui->textBrowser, SIGNAL(forwardAvailable(bool)), this , SLOT(forwardAvailable(bool)));

  QStringList docPath;

  docPath << "doc";
  docPath << (QDir::currentPath() + "/doc");
  docPath << ("/usr/share/Lua-Quick-Try-Out/doc");
  docPath << ("/usr/local/share/Lua-Quick-Try-Out/doc");

  ui->textBrowser->setSearchPaths(docPath);
  ui->textBrowser->setSource(QUrl("func_doc.html"));
  ui->textBrowser->setReadOnly(true);
}

//-----------------------------------------------------------------------------

WindowFunctionHelp::~WindowFunctionHelp()
{
  delete ui;
}

//-----------------------------------------------------------------------------

void WindowFunctionHelp::backwardAvailable(bool available)
{
  m_actionBackward->setEnabled(available);
}

//-----------------------------------------------------------------------------

void WindowFunctionHelp::forwardAvailable(bool available)
{
  m_actionForward->setEnabled(available);
}

//-----------------------------------------------------------------------------

